# -*- coding: utf-8 -*-
#
# This file is part of OArepo.
# Copyright (C) 2020 CESNET.
#
# OArepo is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""CESNET, UCT Prague and NTK wrapper around Invenio v3."""

import os

from setuptools import find_packages, setup

readme = open('README.md').read()

extras_require = {
    'tests': [
        'alembic==1.7.5',
        'amqp==5.0.9',
        'aniso8601==9.0.1',
        'appnope==0.1.2',
        'arrow==1.2.1',
        'asttokens==2.0.5',
        'async-generator==1.10',
        'atomicwrites==1.4.0',
        'attrs==21.4.0',
        'autosemver==0.5.5',
        'babel==2.9.1',
        'babel-edtf==1.0.0',
        'backcall==0.2.0',
        'base32-lib==1.0.2',
        'billiard==3.6.4.0',
        'black==21.12b0',
        'bleach==4.1.0',
        'blinker==1.4',
        'boto3==1.20.44',
        'botocore==1.23.44',
        'build==0.7.0',
        'cachelib==0.6.0',
        'cchardet==2.1.7',
        'celery==5.0.5',
        'certifi==2021.10.8',
        'cffi==1.15.0',
        'charset-normalizer==2.0.10',
        'check-manifest==0.47',
        'click==7.1.2',
        'click-default-group==1.2.2',
        'click-didyoumean==0.3.0',
        'click-plugins==1.1.1',
        'click-repl==0.2.0',
        'colorama==0.4.4',
        'coverage==5.5',
        'cryptography==36.0.1',
        'decorator==5.1.1',
        'defusedxml==0.7.1',
        'deprecated==1.2.13',
        'dnspython==2.2.0',
        'docker-services-cli==0.3.1',
        'dojson==1.4.0',
        'dulwich==0.19.16',
        'edtf==4.0.1',
        'elasticsearch==7.13.4',
        'elasticsearch-dsl==7.4.0',
        'email-validator==1.1.3',
        'entrypoints==0.3',
        'executing==0.8.2',
        'flask==1.1.2',
        'flask-admin==1.5.8',
        'flask-alembic==2.0.1',
        'flask-babelex==0.9.4',
        'flask-breadcrumbs==0.5.1',
        'flask-caching==1.10.1',
        'flask-celeryext==0.3.4',
        'flask-collect-invenio==1.4.0',
        'flask-cors==3.0.10',
        'flask-iiif==0.6.2',
        'flask-kvsession-invenio==0.6.3',
        'flask-limiter==1.1.0',
        'flask-login==0.4.1',
        'flask-mail==0.9.1',
        'flask-menu==0.7.2',
        'flask-oauthlib==0.9.6',
        'flask-principal==0.4.0',
        'flask-resources==0.7.2',
        'flask-restful==0.3.9',
        'flask-security==3.0.0',
        'flask-shell-ipython==0.4.1',
        'flask-sqlalchemy==2.4.4',
        'flask-talisman==0.8.1',
        'flask-webpackext==1.0.2',
        'flask-wtf==0.15.1',
        'fs==0.5.4',
        'ftfy==6.0.3',
        'future==0.18.2',
        'geojson==2.5.0',
        'h11==0.13.0',
        'idna==3.3',
        'idutils==1.1.9',
        'importlib-metadata==4.10.1',
        'importlib-resources==5.4.0',
        'infinity==1.5',
        'iniconfig==1.1.1',
        'intervals==0.9.2',
        'invenio==3.5.0a2',
        'invenio-access==1.4.2',
        'invenio-accounts==1.4.8',
        'invenio-admin==1.3.1',
        'invenio-app==1.3.3',
        'invenio-assets==1.2.7',
        'invenio-base==1.2.5',
        'invenio-cache==1.1.0',
        'invenio-celery==1.2.2',
        'invenio-config==1.0.3',
        'invenio-db==1.0.9',
        'invenio-files-rest==1.2.0',
        'invenio-formatter==1.1.3',
        'invenio-i18n==1.3.1',
        'invenio-iiif==1.1.1',
        'invenio-indexer==1.2.1',
        'invenio-jsonschemas==1.1.3',
        'invenio-logging==1.3.0',
        'invenio-mail==1.0.2',
        'invenio-oaiserver==1.2.2',
        'invenio-oauth2server==1.3.4',
        'invenio-oauthclient==1.5.4',
        'invenio-pidstore==1.2.2',
        'invenio-previewer==1.3.4',
        'invenio-records==1.4.0',
        'invenio-records-files==1.2.1',
        'invenio-records-permissions==0.13.0',
        'invenio-records-resources==0.6.2',
        'invenio-records-rest==1.8.0',
        'invenio-records-ui==1.2.0',
        'invenio-rest==1.2.8',
        'invenio-search==1.4.2',
        'invenio-search-ui==2.0.3',
        'invenio-theme==1.3.10',
        'ipython==8.0.1',
        'ipython-genutils==0.2.0',
        'isbnid-fork==0.5.2',
        'isort==5.10.1',
        'itsdangerous==2.0.1',
        'jedi==0.18.1',
        'jinja2==3.0.3',
        'jmespath==0.10.0',
        'jsmin==3.0.1',
        'jsonpatch==1.32',
        'jsonpointer==2.2',
        'jsonref==0.2',
        'jsonresolver==0.3.1',
        'jsonschema==3.2.0',
        'jupyter-client==7.1.2',
        'jupyter-core==4.9.1',
        'kombu==5.2.3',
        'limits==1.6',
        'lxml==4.7.1',
        'mako==1.1.6',
        'markupsafe==2.0.1',
        'marshmallow==3.14.1',
        'marshmallow-oneofschema==3.0.1',
        'marshmallow-utils==0.4.0',
        'matplotlib-inline==0.1.3',
        'maxminddb==2.2.0',
        'maxminddb-geolite2==2018.703',
        'mistune==2.0.2',
        'msgpack==1.0.3',
        'mypy-extensions==0.4.3',
        'nbconvert==5.5.0',
        'nbformat==5.1.3',
        'nest-asyncio==1.5.4',
        'node-semver==0.1.1',
        'oauthlib==2.1.0',
        'outcome==1.1.0',
        'packaging==21.3',
        'pandocfilters==1.5.0',
        'parso==0.8.3',
        'passlib==1.7.4',
        'pathspec==0.9.0',
        'pep517==0.12.0',
        'pexpect==4.8.0',
        'pickleshare==0.7.5',
        'pillow==9.0.0',
        'platformdirs==2.4.1',
        'pluggy==0.13.1',
        'prompt-toolkit==3.0.25',
        'psycopg2-binary==2.9.3',
        'ptyprocess==0.7.0',
        'pure-eval==0.2.2',
        'py==1.11.0',
        'pycodestyle==2.8.0',
        'pycountry==22.1.10',
        'pycparser==2.21',
        'pydocstyle==6.1.1',
        'pygments==2.11.2',
        'pyjwt==2.3.0',
        'pynpm==0.1.2',
        'pyopenssl==21.0.0',
        'pyparsing==3.0.7',
        'pyrsistent==0.18.1',
        'pytest==6.2.5',
        'pytest-cov==3.0.0',
        'pytest-flask==1.2.0',
        'pytest-invenio[docs]==1.4.2',
        'pytest-isort==2.0.0',
        'pytest-pycodestyle==2.2.0',
        'pytest-pydocstyle==2.2.0',
        'python-dateutil==2.8.2',
        'pytz==2021.3',
        'pywebpack==1.2.0',
        'pyzmq==22.3.0',
        'redis==4.1.2',
        'requests==2.27.1',
        'requests-oauthlib==1.1.0',
        's3-client-lib==0.1.9.post1',
        's3transfer==0.5.0',
        'selenium==4.1.0',
        'sentry-sdk==1.5.4',
        'simplejson==3.17.6',
        'simplekv==0.14.1',
        'six==1.16.0',
        'sniffio==1.2.0',
        'snowballstemmer==2.2.0',
        'sortedcontainers==2.4.0',
        'speaklater==1.3',
        'sqlalchemy==1.3.24',
        'sqlalchemy-continuum==1.3.12',
        'sqlalchemy-utils==0.35.0',
        'stack-data==0.1.4',
        'testpath==0.5.0',
        'toml==0.10.2',
        'tomli==1.2.3',
        'tornado==5.1.1',
        'traitlets==5.1.1',
        'trio==0.19.0',
        'trio-websocket==0.9.2',
        'typing-extensions==4.0.1',
        'ua-parser==0.10.0',
        'uritemplate==4.1.1',
        'uritools==4.0.0',
        'urllib3==1.26.8',
        'validators==0.18.2',
        'vine==5.0.0',
        'wand==0.6.7',
        'wcwidth==0.2.5',
        'webargs==5.5.3',
        'webencodings==0.5.1',
        'werkzeug==2.0.2',
        'wrapt==1.13.3',
        'wsproto==1.0.0',
        'wtforms==2.3.3',
        'wtforms-alchemy==0.18.0',
        'wtforms-components==0.10.5',
        'xmltodict==0.12.0',
        'zipp==3.7.0',
    ]
}

setup_requires = [
    'pytest-runner>=3.0.0,<5',
]

install_requires = [
    'alembic==1.7.5',
    'amqp==5.0.9',
    'aniso8601==9.0.1',
    'appnope==0.1.2',
    'arrow==1.2.1',
    'asttokens==2.0.5',
    'attrs==21.4.0',
    'autosemver==0.5.5',
    'babel==2.9.1',
    'babel-edtf==1.0.0',
    'backcall==0.2.0',
    'base32-lib==1.0.2',
    'billiard==3.6.4.0',
    'black==21.12b0',
    'bleach==4.1.0',
    'blinker==1.4',
    'boto3==1.20.44',
    'botocore==1.23.44',
    'cachelib==0.6.0',
    'cchardet==2.1.7',
    'celery==5.0.5',
    'certifi==2021.10.8',
    'cffi==1.15.0',
    'charset-normalizer==2.0.10',
    'click==7.1.2',
    'click-default-group==1.2.2',
    'click-didyoumean==0.3.0',
    'click-plugins==1.1.1',
    'click-repl==0.2.0',
    'colorama==0.4.4',
    'cryptography==36.0.1',
    'decorator==5.1.1',
    'defusedxml==0.7.1',
    'deprecated==1.2.13',
    'dnspython==2.2.0',
    'dojson==1.4.0',
    'dulwich==0.19.16',
    'edtf==4.0.1',
    'elasticsearch==7.13.4',
    'elasticsearch-dsl==7.4.0',
    'email-validator==1.1.3',
    'entrypoints==0.3',
    'executing==0.8.2',
    'flask==1.1.2',
    'flask-admin==1.5.8',
    'flask-alembic==2.0.1',
    'flask-babelex==0.9.4',
    'flask-breadcrumbs==0.5.1',
    'flask-caching==1.10.1',
    'flask-celeryext==0.3.4',
    'flask-collect-invenio==1.4.0',
    'flask-cors==3.0.10',
    'flask-iiif==0.6.2',
    'flask-kvsession-invenio==0.6.3',
    'flask-limiter==1.1.0',
    'flask-login==0.4.1',
    'flask-mail==0.9.1',
    'flask-menu==0.7.2',
    'flask-oauthlib==0.9.6',
    'flask-principal==0.4.0',
    'flask-resources==0.7.2',
    'flask-restful==0.3.9',
    'flask-security==3.0.0',
    'flask-shell-ipython==0.4.1',
    'flask-sqlalchemy==2.4.4',
    'flask-talisman==0.8.1',
    'flask-webpackext==1.0.2',
    'flask-wtf==0.15.1',
    'fs==0.5.4',
    'ftfy==6.0.3',
    'future==0.18.2',
    'geojson==2.5.0',
    'idna==3.3',
    'idutils==1.1.9',
    'importlib-metadata==4.10.1',
    'importlib-resources==5.4.0',
    'infinity==1.5',
    'intervals==0.9.2',
    'invenio==3.5.0a2',
    'invenio-access==1.4.2',
    'invenio-accounts==1.4.8',
    'invenio-admin==1.3.1',
    'invenio-app==1.3.3',
    'invenio-assets==1.2.7',
    'invenio-base==1.2.5',
    'invenio-cache==1.1.0',
    'invenio-celery==1.2.2',
    'invenio-config==1.0.3',
    'invenio-db==1.0.9',
    'invenio-files-rest==1.2.0',
    'invenio-formatter==1.1.3',
    'invenio-i18n==1.3.1',
    'invenio-iiif==1.1.1',
    'invenio-indexer==1.2.1',
    'invenio-jsonschemas==1.1.3',
    'invenio-logging==1.3.0',
    'invenio-mail==1.0.2',
    'invenio-oaiserver==1.2.2',
    'invenio-oauth2server==1.3.4',
    'invenio-oauthclient==1.5.4',
    'invenio-pidstore==1.2.2',
    'invenio-previewer==1.3.4',
    'invenio-records==1.4.0',
    'invenio-records-files==1.2.1',
    'invenio-records-permissions==0.13.0',
    'invenio-records-resources==0.6.2',
    'invenio-records-rest==1.8.0',
    'invenio-records-ui==1.2.0',
    'invenio-rest==1.2.8',
    'invenio-search==1.4.2',
    'invenio-search-ui==2.0.3',
    'invenio-theme==1.3.10',
    'ipython==8.0.1',
    'ipython-genutils==0.2.0',
    'isbnid-fork==0.5.2',
    'itsdangerous==2.0.1',
    'jedi==0.18.1',
    'jinja2==3.0.3',
    'jmespath==0.10.0',
    'jsmin==3.0.1',
    'jsonpatch==1.32',
    'jsonpointer==2.2',
    'jsonref==0.2',
    'jsonresolver==0.3.1',
    'jsonschema==3.2.0',
    'jupyter-client==7.1.2',
    'jupyter-core==4.9.1',
    'kombu==5.2.3',
    'limits==1.6',
    'lxml==4.7.1',
    'mako==1.1.6',
    'markupsafe==2.0.1',
    'marshmallow==3.14.1',
    'marshmallow-oneofschema==3.0.1',
    'marshmallow-utils==0.4.0',
    'matplotlib-inline==0.1.3',
    'maxminddb==2.2.0',
    'maxminddb-geolite2==2018.703',
    'mistune==2.0.2',
    'msgpack==1.0.3',
    'mypy-extensions==0.4.3',
    'nbconvert==5.5.0',
    'nbformat==5.1.3',
    'nest-asyncio==1.5.4',
    'node-semver==0.1.1',
    'oauthlib==2.1.0',
    'packaging==21.3',
    'pandocfilters==1.5.0',
    'parso==0.8.3',
    'passlib==1.7.4',
    'pathspec==0.9.0',
    'pexpect==4.8.0',
    'pickleshare==0.7.5',
    'pillow==9.0.0',
    'platformdirs==2.4.1',
    'pluggy==0.13.1',
    'prompt-toolkit==3.0.25',
    'psycopg2-binary==2.9.3',
    'ptyprocess==0.7.0',
    'pure-eval==0.2.2',
    'py==1.11.0',
    'pycountry==22.1.10',
    'pycparser==2.21',
    'pygments==2.11.2',
    'pyjwt==2.3.0',
    'pynpm==0.1.2',
    'pyparsing==3.0.7',
    'pyrsistent==0.18.1',
    'python-dateutil==2.8.2',
    'pytz==2021.3',
    'pywebpack==1.2.0',
    'pyzmq==22.3.0',
    'redis==4.1.2',
    'requests==2.27.1',
    'requests-oauthlib==1.1.0',
    's3-client-lib==0.1.9.post1',
    's3transfer==0.5.0',
    'sentry-sdk==1.5.4',
    'simplejson==3.17.6',
    'simplekv==0.14.1',
    'six==1.16.0',
    'speaklater==1.3',
    'sqlalchemy==1.3.24',
    'sqlalchemy-continuum==1.3.12',
    'sqlalchemy-utils==0.35.0',
    'stack-data==0.1.4',
    'testpath==0.5.0',
    'tomli==1.2.3',
    'tornado==5.1.1',
    'traitlets==5.1.1',
    'typing-extensions==4.0.1',
    'ua-parser==0.10.0',
    'uritemplate==4.1.1',
    'uritools==4.0.0',
    'urllib3==1.26.8',
    'validators==0.18.2',
    'vine==5.0.0',
    'wand==0.6.7',
    'wcwidth==0.2.5',
    'webargs==5.5.3',
    'webencodings==0.5.1',
    'werkzeug==2.0.2',
    'wrapt==1.13.3',
    'wtforms==2.3.3',
    'wtforms-alchemy==0.18.0',
    'wtforms-components==0.10.5',
    'xmltodict==0.12.0',
    'zipp==3.7.0',
]

packages = find_packages()

# Get the version string. Cannot be done with import!
g = {}
with open(os.path.join('oarepo', 'version.py'), 'rt') as fp:
    exec(fp.read(), g)
    version = g['__version__']

setup(
    name='oarepo',
    version=version,
    description=__doc__,
    long_description=readme,
    long_description_content_type='text/markdown',
    keywords='oarepo invenio',
    license='MIT',
    author='UCT Prague, CESNET z.s.p.o., NTK',
    author_email='miroslav.simek@vscht.cz',
    url='https://github.com/oarepo/oarepo',
    packages=packages,
    zip_safe=False,
    include_package_data=True,
    platforms='any',
    entry_points={},
    extras_require=extras_require,
    install_requires=install_requires,
    setup_requires=setup_requires,
    tests_require=extras_require['tests'],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Development Status :: 3 - Alpha',
        # 'Development Status :: 5 - Production/Stable',
    ],
)
